==> leo-6.8.1-py3-none-any.whl: leo/core/leoVersion.py <==
#@+leo-ver=5-thin
#@+node:ekr.20090717092906.12765: * @file leoVersion.py
"""
A module holding the following version-related info:

leoVersion.static_date: The date of official releases.
                        Also used when the git repo is not available.
leoVersion.version:     Leo's version number.
"""
#@+<< version dates >>
#@+node:ekr.20141117073519.12: ** << version dates >>
#@@nocolor-node
#@+at
# 4.5.1:  September 14, 2008
# 4.6.1:  July 30, 2009.
# 4.7.1:  February 26, 2010.
# 4.8:    November 26, 2010.
# 4.9:    June 21, 2011.
# 4.10:   March 29, 2012.
# 4.11:   November 6, 2013.
# 5.0:    November 24, 2014.
# 5.1:    April 17, 2015.
# 5.2:    March 18, 2016.
# 5.3:    May 2, 2016.
# 5.4:    October 22, 2016.
# 5.5:    March 23, 2017.
# 5.6:    September 27, 2017.
# 5.7:    February 27, 2018.
# 5.7.1:  April 6, 2018.
# 5.7.2:  May 7, 2018.
# 5.7.3:  May 27, 2018.
# 5.8:    August 29, 2018.
# 5.9:    May 5, 2019.
# 6.0:    August 2, 2019.
# 6.1:    November 8, 2019.
# 6.2:    March 27, 2020.
# 6.3:    November 6, 2020.
# 6.4:    September 20, 2021.
# 6.5:    October 22, 2021.
# 6.6:    March 31, 2022.
# 6.6.1:  April 28, 2022.
# 6.6.2:  May 25, 2022.
# 6.6.3:  July 22, 2022.
# 6.7.0:  September 26, 2022.
# 6.7.1:  November 8, 2022.
# 6.7.2:  March 1, 2023.
# 6.7.3:  May 7, 2023.
# 6.7.4:  August 17, 2023.
# 6.7.5:  November 7, 2023.
# 6.7.6:  December 19, 2023.
# 6.7.7:  January 20, 2024.
# 6.7.8:  March 22, 2024.
# 6.8.0:  July 3, 2024.
# 6.8.1:  July 27, 2024.
#@-<< version dates >>
version = '6.8.1'
static_date = 'July 16, 2024'
#@@language python
#@@tabwidth -4
#@-leo

==> leo-6.8.2-py3-none-any.whl: leo/core/leoVersion.py <==
#@+leo-ver=5-thin
#@+node:ekr.20090717092906.12765: * @file leoVersion.py
"""
A module holding the following version-related info:

leoVersion.static_date: The date of official releases.
                        Also used when the git repo is not available.
leoVersion.version:     Leo's version number.
"""
#@+<< version dates >>
#@+node:ekr.20141117073519.12: ** << version dates >>
#@@nocolor-node
#@+at
# 4.5.1:  September 14, 2008
# 4.6.1:  July 30, 2009.
# 4.7.1:  February 26, 2010.
# 4.8:    November 26, 2010.
# 4.9:    June 21, 2011.
# 4.10:   March 29, 2012.
# 4.11:   November 6, 2013.
# 5.0:    November 24, 2014.
# 5.1:    April 17, 2015.
# 5.2:    March 18, 2016.
# 5.3:    May 2, 2016.
# 5.4:    October 22, 2016.
# 5.5:    March 23, 2017.
# 5.6:    September 27, 2017.
# 5.7:    February 27, 2018.
# 5.7.1:  April 6, 2018.
# 5.7.2:  May 7, 2018.
# 5.7.3:  May 27, 2018.
# 5.8:    August 29, 2018.
# 5.9:    May 5, 2019.
# 6.0:    August 2, 2019.
# 6.1:    November 8, 2019.
# 6.2:    March 27, 2020.
# 6.3:    November 6, 2020.
# 6.4:    September 20, 2021.
# 6.5:    October 22, 2021.
# 6.6:    March 31, 2022.
# 6.6.1:  April 28, 2022.
# 6.6.2:  May 25, 2022.
# 6.6.3:  July 22, 2022.
# 6.7.0:  September 26, 2022.
# 6.7.1:  November 8, 2022.
# 6.7.2:  March 1, 2023.
# 6.7.3:  May 7, 2023.
# 6.7.4:  August 17, 2023.
# 6.7.5:  November 7, 2023.
# 6.7.6:  December 19, 2023.
# 6.7.7:  January 20, 2024.
# 6.7.8:  March 22, 2024.
# 6.8.0:  July 3, 2024.
# 6.8.1:  July 27, 2024.
# 6.8.2:  November 7, 2024.
#@-<< version dates >>
version = '6.8.2'
static_date = 'November 7, 2024'
#@@language python
#@@tabwidth -4
#@-leo
